@@ -3,13 +3,15 @@
 
 # Find anagrams of...
 LETTERSET=etaoinshrdlu
+FILTER='.......'       # How many letters minimum?
+#       1234567
 
 anagram "$LETTERSET" | # Find all anagrams of the letterset...
-grep '.......' |       # With at least 7 letters,
+grep "$FILTER" |       # With at least 7 letters,
 grep '^is' |           # starting with 'is'
 grep -v 's$' |         # no plurals
 grep -v 'ed$'          # no past tense verbs
-# Possible to add many combinations of conditions.
+# Possible to add many combinations of conditions and filters.
 
 #  Uses "anagram" utility
 #+ that is part of the author's "yawl" word list package.
@@ -18,8 +20,20 @@ grep -v 'ed$'          # no past tense verbs
 
 exit 0                 # End of code.
 
+
 bash$ sh agram.sh
 islander
 isolate
 isolead
 isotheral
+
+
+
+#  Exercises:
+#  ---------
+#  Modify this script to take the LETTERSET as a command-line parameter.
+#  Parameterize the filters in lines 11 - 13 (as with $FILTER),
+#+ so that they can be specified by passing arguments to a function.
+
+#  For a slightly different approach to anagramming,
+#+ see the agram2.sh script.
