@@ -17,7 +17,7 @@ assert ()                 #  If condition false,
   if [ ! $1 ] 
   then
     echo "Assertion failed:  \"$1\""
-    echo "File $0, line $lineno"
+    echo "File \"$0\", line $lineno"
     exit $E_ASSERT_FAILED
   # else
   #   return
@@ -38,6 +38,8 @@ assert "$condition" $LINENO
 
 # Some commands.
 # ...
+echo "This statement echoes only if the \"assert\" does not fail."
+# ...
 # Some more commands.
 
 exit 0
