@@ -6,7 +6,7 @@ previous=$var1
 while echo "previous-variable = $previous"
       echo
       previous=$var1
-      [ "$var1" != end ] # Keeps track of what "var1" was previously.
+      [ "$var1" != end ] # Keeps track of what $var1 was previously.
       # Four conditions on "while", but only last one controls loop.
       # The *last* exit status is the one that counts.
 do
