@@ -1,4 +1,5 @@
 #!/bin/bash
+# secret-pw.sh: secret password
 
 echo
 echo -n "Enter password "
@@ -7,7 +8,8 @@ echo "password is $passwd"
 echo -n "If someone had been looking over your shoulder, "
 echo "your password would have been compromised."
 
-echo && echo  # Two line-feeds in an "and list".
+echo && echo  # Two line-feeds in an "and list."
+
 
 stty -echo    # Turns off screen echo.
 
@@ -20,3 +22,5 @@ echo
 stty echo     # Restores screen echo.
 
 exit 0
+
+# Do an 'info stty' for more on this useful-but-tricky command.
